@@ -66,46 +66,46 @@ date range limited by 32 bit signed integers (around 1902 to 2038).
   my $graph = SVG::TT::Graph::TimeSeries->new({
   
     # Optional - defaults shown
-    'height'            => 500,
-    'width'             => 300,
+    'height'              => 500,
+    'width'               => 300,
 
-    'show_y_labels'     => 1,
-    'scale_divisions'   => '',
-    'min_scale_value'   => 0,
-    'max_scale_value'   => '',
+    'show_y_labels'       => 1,
+    'scale_divisions'     => '',
+    'min_scale_value'     => 0,
+    'max_scale_value'     => '',
 
-    'show_x_labels'     => 1,    
+    'show_x_labels'       => 1,    
     'timescale_divisions' => '',
     'min_timescale_value' => '',
     'max_timescale_value' => '',
-    'x_label_format'    => '%Y-%m-%d %H:%M:%S',
-    'stagger_x_labels'  => 0,
-    'rotate_x_labels'   => 0,
-    'y_label_formatter' => sub { return @_ },
-    'x_label_formatter' => sub { return @_ },
+    'x_label_format'      => '%Y-%m-%d %H:%M:%S',
+    'stagger_x_labels'    => 0,
+    'rotate_x_labels'     => 0,
+    'y_label_formatter'   => sub { return @_ },
+    'x_label_formatter'   => sub { return @_ },
     
-    'show_data_points'  => 1,
-    'show_data_values'  => 1,
-    'rollover_values'   => 0,
+    'show_data_points'    => 1,
+    'show_data_values'    => 1,
+    'rollover_values'     => 0,
     
-    'area_fill'         => 0,    
+    'area_fill'           => 0,
 
-    'show_x_title'      => 0,
-    'x_title'           => 'X Field names',
+    'show_x_title'        => 0,
+    'x_title'             => 'X Field names',
 
-    'show_y_title'      => 0,
-    'y_title'           => 'Y Scale',
+    'show_y_title'        => 0,
+    'y_title'             => 'Y Scale',
 
-    'show_graph_title'      => 0,
-    'graph_title'           => 'Graph Title',
-    'show_graph_subtitle'   => 0,
-    'graph_subtitle'        => 'Graph Sub Title',
-    'key'                   => 0,
-    'key_position'          => 'right',
+    'show_graph_title'    => 0,
+    'graph_title'         => 'Graph Title',
+    'show_graph_subtitle' => 0,
+    'graph_subtitle'      => 'Graph Sub Title',
+    'key'                 => 0,
+    'key_position'        => 'right',
 
     # Stylesheet defaults
-    'style_sheet'             => '/includes/graph.css', # internal stylesheet
-    'random_colors'           => 0,
+    'style_sheet'         => '/includes/graph.css', # internal stylesheet
+    'random_colors'       => 0,
   });
 
 The constructor takes a hash reference with values defaulted to those
@@ -404,6 +404,7 @@ L<SVG::TT::Graph::Bar>,
 L<SVG::TT::Graph::BarHorizontal>,
 L<SVG::TT::Graph::BarLine>,
 L<SVG::TT::Graph::Pie>,
+L<SVG::TT::Graph::XY>,
 L<Compress::Zlib>,
 L<XML::Tidy>
 
